@@ -3,12 +3,14 @@ darts
 -----
 """
 
+import os
+
 import matplotlib as mpl
 from matplotlib import cycler
 
 from .timeseries import TimeSeries, concatenate
 
-__version__ = "0.19.0"
+__version__ = "0.20.0"
 
 colors = cycler(
     color=["black", "003DFD", "b512b8", "11a9ba", "0d780f", "f77f07", "ba0f0f"]
@@ -37,4 +39,5 @@ u8plots_mplstyle = {
 }
 
 
-mpl.rcParams.update(u8plots_mplstyle)
+if os.getenv("DARTS_CONFIGURE_MATPLOTLIB", "1") != "0":
+    mpl.rcParams.update(u8plots_mplstyle)
