@@ -9,4 +9,9 @@ from .fittable_data_transformer import FittableDataTransformer
 from .invertible_data_transformer import InvertibleDataTransformer
 from .mappers import InvertibleMapper, Mapper
 from .missing_values_filler import MissingValuesFiller
+from .reconciliation import (
+    BottomUpReconciliator,
+    MinTReconciliator,
+    TopDownReconciliator,
+)
 from .scaler import Scaler
