@@ -110,3 +110,22 @@ if TORCH_AVAILABLE:
         def test_pred_length(self):
             series = tg.linear_timeseries(length=100)
             self.helper_test_pred_length(TransformerModel, series)
+
+        def test_activations(self):
+            with self.assertRaises(ValueError):
+                model1 = TransformerModel(
+                    input_chunk_length=1, output_chunk_length=1, activation="invalid"
+                )
+                model1.fit(self.series, epochs=1)
+
+            # internal activation function
+            model2 = TransformerModel(
+                input_chunk_length=1, output_chunk_length=1, activation="gelu"
+            )
+            model2.fit(self.series, epochs=1)
+
+            # glue variant FFN
+            model3 = TransformerModel(
+                input_chunk_length=1, output_chunk_length=1, activation="SwiGLU"
+            )
+            model3.fit(self.series, epochs=1)
